/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.hql.impl.model;

import org.cementframework.querybyproxy.hql.impl.compiler.QueryCompiler;
import org.cementframework.querybyproxy.shared.api.model.FromClause;
import org.cementframework.querybyproxy.shared.api.model.joins.QueryJoin;

/**
 * Represents a "from" clause.
 *
 * @author allenparslow
 */
public class HqlFromClauseVisitor implements QueryFragmentVisitor<FromClause> {

    /**
     * {@inheritDoc}
     */
    public void visit(FromClause from,
            HqlQueryVisitorStrategy strategy,
            QueryCompiler resolver) {

        resolver.appendSpaceIfRequired();
        resolver.append("from ");
        resolver.append(from.getRootName());
        resolver.append(" ");
        resolver.append(resolver.getAliasResolver().getIdentifactionVariable(from.getTargetProxy())
                .getName());

        for (QueryJoin join : from.getJoinMap().values()) {
            strategy.visit(join, resolver);
        }
    }

}
