/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.cementframework.querybyproxy.hql.impl.model.joins;

import org.cementframework.querybyproxy.hql.impl.compiler.QueryCompiler;
import org.cementframework.querybyproxy.hql.impl.model.HqlQueryVisitorStrategy;
import org.cementframework.querybyproxy.hql.impl.model.QueryFragmentVisitor;
import org.cementframework.querybyproxy.shared.api.model.joins.NestedPropertyJoin;
import org.cementframework.querybyproxy.shared.api.model.joins.QueryJoinModifier;

/**
 * Represents a proxy join for a from-clause.
 *
 * @author allenparslow
 */
public class HqlNestedProxyJoinVisitor implements QueryFragmentVisitor<NestedPropertyJoin> {

    /**
     * {@inheritDoc}
     */
    public void visit(NestedPropertyJoin join,
            HqlQueryVisitorStrategy strategy,
            QueryCompiler resolver) {

        Object parent = join.getParent().getTargetProxy();

        resolver.append(join.getJoinType().getText());
        if (!QueryJoinModifier.NONE.equals(join.getJoinModifier())) {
            resolver.append(join.getJoinModifier().getText());
        }
        resolver.append(resolver.getAliasResolver().getIdentifactionVariable(parent).getName());
        resolver.append(".");
        resolver.append(join.getPath());
        resolver.append(" ");
        resolver.append(resolver.getAliasResolver().getIdentifactionVariable(join.getTargetProxy())
                .getName());
    }
}
